Advancelist class
Checks if you are awesome. Spoiler: you are.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
findMax(
{required List list}) → dynamic -
this method can find the max intordouble from dynamic list
list -
findMin(
{required List list}) → dynamic -
this method can find the min intordouble from dynamic list
list -
listEqule(
{required List first, required List second}) → bool - this method can compare two Lists
-
listremover(
{required List first, required List second}) → void -
this method can remove the same Element
int , String ,doublebetween two List